pub enum Error {
PathNotFound(String),
InvalidPathName(PathBuf),
EmptyFileName(PathBuf),
Json(Error),
Io(Error),
MaxAttemptsExceeded {
name: String,
max_attempts: usize,
},
}Expand description
Error type for fallible operations in this crate.
Implements std::error::Error via thiserror.
Variants
PathNotFound(String)
Expected resource behind a path was not found.
InvalidPathName(PathBuf)
Failed to extract a valid name from the path.
EmptyFileName(PathBuf)
Filename was empty
Json(Error)
JSON (de)serialization error, from serde_json::Error.
Io(Error)
I/O error, from std::io::Error.
MaxAttemptsExceeded
Exceeded maximum attempts while searching for an available note name.
This occurs when creating a note with a name that already exists, and all numbered variants (e.g., “Name 1”, “Name 2”, …, “Name 999”) also exist.